import QtQuick 2.0
import Sailfish.Silica 1.0
import "apiconstants.js" as APIConstants

Dialog {
	id: page
	onStatusChanged: if (status === PageStatus.Active) pageStack.pushAttached(loggingin);

	canNavigateForward: zipfield.acceptableInput && dobfield.acceptableInput && codefield.acceptableInput

	Column {
		width: parent.width

		DialogHeader {
			cancelText: qsTr('Change clinic')
			acceptText: qsTr('Log in')
		}

		TextField {
			width: parent.width
			id: zipfield
			label: qsTr('Zipcode')
			labelVisible: true
			placeholderText: '1234AB'
			EnterKey.enabled: text.length === 6
			EnterKey.iconSource: 'image://theme/icon-m-enter-next'
			EnterKey.onClicked: dobfield.focus = true
			validator: RegExpValidator {
				regExp: /^\d{4}[A-Z]{2}$/
			}
		}

		TextField {
			width: parent.width
			id: dobfield
			label: qsTr('Date of Birth')
			labelVisible: true
			onClicked: {
				var dialog = pageStack.push(pickerComponent);

				dialog.accepted.connect(function () {
					function naivepad(num) {
						num = num.toString();
						return num.length === 1 ? '0' + num : num;
					}

					dobfield.text = naivepad(dialog.day) + naivepad(dialog.month) + dialog.year;
				});
			}
			placeholderText: '01012000'
			validator: RegExpValidator {
				regExp: /^[0-3]\d[01]\d{5}$/
			}
			EnterKey.enabled: text.length === 8
			EnterKey.iconSource: 'image://theme/icon-m-enter-next'
			EnterKey.onClicked: codefield.focus = true

			Component {
				id: pickerComponent
				DatePickerDialog {}
			}
		}

		PasswordField {
			width: parent.width
			id: codefield
			label: qsTr('Online Code')
			placeholderText: '12345'
			EnterKey.enabled: text.length
			EnterKey.iconSource: 'image://theme/icon-m-enter-accept'
			EnterKey.onClicked: pageStack.navigateForward(PageStackAction.Animated)
			labelVisible: true
		}

		Component {
			id: loggingin
			Page {
				PageBusyIndicator {
					running: true
				}
				onStatusChanged: if (status === PageStatus.Active) {
					var xhr = new XMLHttpRequest;

					function reperror() {
						pageStack.navigateBack();
					}

					xhr.onreadystatechange = function () {
						var i;
						if (xhr.readyState === XMLHttpRequest.DONE) {
							try {
								settings.setValue('usercode', xhr.response.user_code);
								pageStack.clear();
								pageStack.replace(Qt.resolvedUrl('MainPage.qml'));
							} catch (e) {
								reperror();
							}
						}
					}
					xhr.onerror = reperror;
					xhr.open('POST', APIConstants.BASE + '/Authenticate', true);
					xhr.setRequestHeader('IORTHO-KEY', APIConstants.APIKEY);
					xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
					xhr.responseType = 'json';
					xhr.send('code=' + settings.getValue('clinic') + '&zipcode=' + zipfield.text + '&date_of_birth=' + dobfield.text + '&online_code=' + codefield.text);
				}
			}
		}
	}
}
