import QtQuick 2.0
import Sailfish.Silica 1.0
import "apiconstants.js" as APIConstants

Page {
	property int numappointments

	id: page
	allowedOrientations: Orientation.All

	PageBusyIndicator {
		running: !listView.model.count
	}

	SilicaListView {
		id: listView
		model: {
			var model = Qt.createQmlObject('import QtQuick 2.0; ListModel {}', parent),
			xhr = new XMLHttpRequest;

			function reperror() {
				model.append({ name: 'An error has occured.' });
			}

			xhr.onreadystatechange = function () {
				var i;
				if (xhr.readyState === XMLHttpRequest.DONE) {
					try {
						model.clear();
						for (i = 0; i < xhr.response.length; ++i)
							model.append(xhr.response[i]);
						numappointments = i;
					} catch (e) {
						reperror();
					}
				}
			}
			xhr.onerror = reperror;
			xhr.open('POST', APIConstants.BASE + '/Appointments', true);
			xhr.setRequestHeader('IORTHO-KEY', APIConstants.APIKEY);
			xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded')
			xhr.responseType = 'json';
			xhr.send('user_code=' + settings.getValue('usercode'));

			return model;
		}

		PullDownMenu {
			MenuItem {
				text: qsTr('Log Out')
				onClicked: {
					settings.removeValue('usercode');
					settings.removeValue('clinic');
					pageStack.replace(Qt.resolvedUrl('ClinicChooser.qml'));
				}
			}
			MenuItem {
				text: qsTr('Show QR code')
				onClicked: pageStack.push(Qt.resolvedUrl('QrView.qml'))
			}
		}

		anchors.fill: parent
		header: PageHeader {
			title: qsTr('Upcoming Appointments')
		}
		delegate: BackgroundItem {
			id: delegate

			Label {
				x: Theme.horizontalPageMargin
				text: start_date.replace('T', ' ') + ' (' + Math.floor((new Date(end_date) - new Date(start_date)) / 60000) + ' min)'
				anchors.top: parent.top
				color: delegate.highlighted ? Theme.secondaryHighlightColor : Theme.secondaryColor
			}

			Label {
				x: Theme.horizontalPageMargin
				text: description
				anchors.bottom: parent.bottom
				color: delegate.highlighted ? Theme.highlightColor : Theme.primaryColor
			}

			onClicked: {
				calendar.addEvent(description, start_date.replace(/[:-]/g, ''), end_date.replace(/[:-]/g, ''));
			}
		}
		VerticalScrollDecorator {}
	}
}
