import QtQuick 2.0
import Sailfish.Silica 1.0
import "apiconstants.js" as APIConstants



Page {
	property string qrurl
	id: page
	allowedOrientations: Orientation.All

	PageBusyIndicator {
		running: !qrurl
	}

	Image {
		// Algorithm Implementation/Miscellaneous/Base64. (2020, April 16). Wikibooks, The Free Textbook Project. Retrieved 19:26, January 8, 2021 from https://en.wikibooks.org/w/index.php?title=Algorithm_Implementation/Miscellaneous/Base64&oldid=3679431.
		function base64_encode(inbuf) {
		  // the result/encoded string, the padding string, and the pad count
		  var base64chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
		  var r = "";
		  var p = "";

		  // resize buffer to multiple of three
		  var s = new Uint8Array(inbuf.length + (inbuf.length%3));
		  s.set(inbuf);

		  // increment over the length of the string, three characters at a time
		  for (var c = 0; c < s.length; c += 3) {
			// these three 8-bit (ASCII) characters become one 24-bit number
			var n = (s[c] << 16) + (s[c+1] << 8) + s[c+2];

			// this 24-bit number gets separated into four 6-bit numbers
			n = [(n >>> 18) & 63, (n >>> 12) & 63, (n >>> 6) & 63, n & 63];

			// those four 6-bit numbers are used as indices into the base64 character list
			r += base64chars[n[0]] + base64chars[n[1]] + base64chars[n[2]] + base64chars[n[3]];
		  }
		   // add the actual padding string, after removing the zero pad
		  return r.substring(0, r.length - p.length) + p;
		}

		id: image
		source: {
			var xhr = new XMLHttpRequest;

			function reperror() {
				pageStack.navigateBack();
			}

			xhr.onreadystatechange = function () {
				try {
					if (xhr.readyState === XMLHttpRequest.DONE)
						image.source = qrurl = 'data:image/png;base64,' + base64_encode(new Uint8Array(xhr.response));
				} catch (e) {
					pageStack.navigateBack();
				}
			}
			xhr.onerror = reperror;
			// what a mess, some api paths are under iOrtho and others under iortho
			xhr.open('GET', APIConstants.BASE.toLowerCase() + '/QRCode?' + settings.getValue('usercode'), true);
			xhr.setRequestHeader('IORTHO-KEY', APIConstants.APIKEY);
			xhr.responseType = 'arraybuffer';
			xhr.send();
			return '';
		}
		anchors.horizontalCenter: parent.horizontalCenter
		anchors.verticalCenter: parent.verticalCenter
		smooth: false
		fillMode: Image.PreserveAspectFit
		width: parent.width
		height: parent.height
	}
}
